@@ -27,7 +27,7 @@ build_time_vars = {'ABIFLAGS': '',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -Wsign-compare '
            '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions -fexceptions '
-           '-fexceptions',
+           '-fexceptions   -O3',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CODECS_COMMON_HEADERS': '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/multibytecodec.h '
@@ -36,9 +36,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-fexceptions',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+ 'CONFIGURE_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
-                            '-Werror=format-security '
+                            '-Wno-complain-wrong-lang -Werror=format-security '
                             '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                             '-Wp,-D_GLIBCXX_ASSERTIONS '
                             '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -669,9 +669,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                     '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                    '-fexceptions -fexceptions -O2 -flto=auto '
+                    '-fexceptions -fexceptions   -O3 -flto=auto '
                     '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
-                    '-pipe -Wall -Werror=format-security '
+                    '-pipe -Wall -Wno-complain-wrong-lang '
+                    '-Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -684,15 +685,16 @@ build_time_vars = {'ABIFLAGS': '',
                     '-Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration -fvisibility=hidden '
-                    '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
-                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+                    '-flto=auto -ffat-lto-objects -fexceptions -g '
+                    '-grecord-gcc-switches -pipe -Wall '
+                    '-Wno-complain-wrong-lang -Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                     '-fstack-protector-strong '
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                     '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-                    '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv  '
+                    '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv -O3 '
                     '-fprofile-use -fprofile-correction '
                     '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
@@ -702,9 +704,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBHACL_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.4/Modules/_hacl/include '
                    '-D_BSD_SOURCE -D_DEFAULT_SOURCE -fno-strict-overflow '
                    '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                   '-fexceptions -fexceptions -fexceptions -O2 -flto=auto '
+                   '-fexceptions -fexceptions -fexceptions   -O3 -flto=auto '
                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
-                   '-pipe -Wall -Werror=format-security '
+                   '-pipe -Wall -Wno-complain-wrong-lang '
+                   '-Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -716,16 +719,16 @@ build_time_vars = {'ABIFLAGS': '',
                    '-ffat-lto-objects -flto-partition=none -g -std=c11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                   '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                   '-Werror=format-security '
+                   '-Wno-complain-wrong-lang -Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                    '-fstack-protector-strong '
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                    '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv  '
+                   '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv -O3 '
                    '-fprofile-use -fprofile-correction '
                    '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
@@ -739,9 +742,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
                     '-fno-strict-overflow -Wsign-compare '
                     '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                    '-fexceptions -fexceptions -O2 -flto=auto '
+                    '-fexceptions -fexceptions   -O3 -flto=auto '
                     '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
-                    '-pipe -Wall -Werror=format-security '
+                    '-pipe -Wall -Wno-complain-wrong-lang '
+                    '-Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -754,15 +758,16 @@ build_time_vars = {'ABIFLAGS': '',
                     '-Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration -fvisibility=hidden '
-                    '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
-                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+                    '-flto=auto -ffat-lto-objects -fexceptions -g '
+                    '-grecord-gcc-switches -pipe -Wall '
+                    '-Wno-complain-wrong-lang -Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                     '-fstack-protector-strong '
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                     '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-                    '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv  '
+                    '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv -O3 '
                     '-fprofile-use -fprofile-correction '
                     '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
@@ -1133,10 +1138,10 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                             '-fexceptions -fexceptions -fexceptions -O2 '
+                             '-fexceptions -fexceptions -fexceptions   -O3 '
                              '-flto=auto -ffat-lto-objects -fexceptions -g '
                              '-grecord-gcc-switches -pipe -Wall '
-                             '-Werror=format-security '
+                             '-Wno-complain-wrong-lang -Werror=format-security '
                              '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1152,9 +1157,9 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden -O2 -flto=auto '
-                             '-ffat-lto-objects -fexceptions -g '
-                             '-grecord-gcc-switches -pipe -Wall '
+                             '-fvisibility=hidden -flto=auto -ffat-lto-objects '
+                             '-fexceptions -g -grecord-gcc-switches -pipe '
+                             '-Wall -Wno-complain-wrong-lang '
                              '-Werror=format-security '
                              '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -1164,17 +1169,17 @@ build_time_vars = {'ABIFLAGS': '',
                              '-m64 -march=z14 -mtune=z15 '
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection  -D_GNU_SOURCE -fPIC '
-                             '-fwrapv  -fprofile-use -fprofile-correction '
+                             '-fwrapv -O3 -fprofile-use -fprofile-correction '
                              '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
                              '-I/builddir/build/BUILD/Python-3.12.4/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare '
               '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-              '-fexceptions -fexceptions',
- 'PY_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+              '-fexceptions -fexceptions   -O3',
+ 'PY_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
-                     '-Werror=format-security '
+                     '-Wno-complain-wrong-lang -Werror=format-security '
                      '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1187,23 +1192,24 @@ build_time_vars = {'ABIFLAGS': '',
                      '-Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                     '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                      '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                     '-Werror=format-security '
+                     '-Wno-complain-wrong-lang -Werror=format-security '
                      '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                      '-fstack-protector-strong '
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                      '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-                     '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv  '
-                     '-fprofile-use -fprofile-correction '
+                     '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv '
+                     '-O3 -fprofile-use -fprofile-correction '
                      '-I/builddir/build/BUILD/Python-3.12.4/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                   '-fexceptions -fexceptions -O2 -flto=auto -ffat-lto-objects '
-                   '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+                   '-fexceptions -fexceptions   -O3 -flto=auto '
+                   '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
+                   '-pipe -Wall -Wno-complain-wrong-lang '
                    '-Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -1216,16 +1222,16 @@ build_time_vars = {'ABIFLAGS': '',
                    '-ffat-lto-objects -flto-partition=none -g -std=c11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                   '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                   '-Werror=format-security '
+                   '-Wno-complain-wrong-lang -Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                    '-fstack-protector-strong '
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                    '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv  '
+                   '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv -O3 '
                    '-fprofile-use -fprofile-correction '
                    '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
@@ -1271,10 +1277,10 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                         '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                        '-fexceptions -fexceptions -O2 -flto=auto '
+                        '-fexceptions -fexceptions   -O3 -flto=auto '
                         '-ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
-                        '-Werror=format-security '
+                        '-Wno-complain-wrong-lang -Werror=format-security '
                         '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
                         '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1287,17 +1293,17 @@ build_time_vars = {'ABIFLAGS': '',
                         '-Wextra -Wno-unused-parameter '
                         '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                        '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                        '-Werror=format-security '
+                        '-Wno-complain-wrong-lang -Werror=format-security '
                         '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
                         '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                         '-fstack-protector-strong '
                         '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                         '-march=z14 -mtune=z15 -fasynchronous-unwind-tables '
-                        '-fstack-clash-protection  -D_GNU_SOURCE -fPIC '
-                        '-fwrapv  -fprofile-use -fprofile-correction '
+                        '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv '
+                        '-O3 -fprofile-use -fprofile-correction '
                         '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
                         '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC',
